# yopycalc
Python Calculator

Simple python calculator

Link to PyPI: https://pypi.org/project/yopycalc/

Install package on your local machine using the command: pip install yopycalc

Reference taken from : 
https://circleci.com/blog/publishing-a-python-package/
https://www.youtube.com/watch?v=4dp4JFpOpX0&ab_channel=srcmake
https://web.archive.org/web/20201214181824/https://www.jeffknupp.com/blog/2013/08/16/open-sourcing-a-python-project-the-right-way/